@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 4016 2008-07-01 17:40:13Z wwalker $"
-__version__   = "$Revision: 4016 $"
-__date__      = "$Date: 2008-07-01 13:40:13 -0400 (Tue, 01 Jul 2008) $"
+__id__        = "$Id: orca.py 4109 2008-08-18 16:24:49Z wwalker $"
+__version__   = "$Revision: 4109 $"
+__date__      = "$Date: 2008-08-18 12:24:49 -0400 (Mon, 18 Aug 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -60,7 +60,6 @@ import unicodedata
 import pyatspi
 import braille
 import debug
-import dbusserver
 import httpserver
 import keynames
 import keybindings
@@ -75,6 +74,9 @@ from input_event import KeyboardEvent
 from input_event import MouseButtonEvent
 from input_event import keyEventToString
 
+if settings.useDBus:
+    import dbusserver
+
 from orca_i18n import _           # for gettext support
 
 if settings.debugMemoryUsage:
@@ -879,8 +881,14 @@ def loadUserSettings(script=None, inputEvent=None):
     global _userSettings
 
     # Shutdown the output drivers and give them a chance to die.
+
+    # Only exit the D-Bus server if we're in an environment where there 
+    # is a D-Bus session bus already running.  This helps prevent nastiness
+    # on the login screen.
     #
-    dbusserver.shutdown()
+    if settings.useDBus:
+        dbusserver.shutdown()
+
     httpserver.shutdown()
     speech.shutdown()
     braille.shutdown()
@@ -991,7 +999,12 @@ def loadUserSettings(script=None, inputEvent=None):
 
     showMainWindowGUI()
 
-    dbusserver.init()
+    # Only start the D-Bus server if we're in an environment where there 
+    # is a D-Bus session bus already running.  This helps prevent nastiness
+    # on the login screen.
+    #
+    if settings.useDBus:
+        dbusserver.init()
     httpserver.init()
 
     return True
