@@ -33,7 +33,7 @@ ngettext = gettext.ngettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/usr", "share", "locale")
+localedir = os.path.join ("/home/wwalker/orca-devel", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
